# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: comms.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'comms.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x63omms.proto\x12\x03\x62os\"\x07\n\x05\x45mpty\"0\n\x06Header\x12\x0b\n\x03Src\x18\x01 \x01(\t\x12\x0b\n\x03\x44st\x18\x02 \x01(\t\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\"\xa0\x01\n\x07GetPair\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\x12\x1e\n\x05\x44type\x18\x03 \x01(\x0e\x32\n.bos.DtypeH\x00\x88\x01\x01\x12!\n\x05\x45rror\x18\x05 \x01(\x0e\x32\r.bos.GetErrorH\x01\x88\x01\x01\x12\x15\n\x08\x45rrorMsg\x18\x06 \x01(\tH\x02\x88\x01\x01\x42\x08\n\x06_DtypeB\x08\n\x06_ErrorB\x0b\n\t_ErrorMsg\"\xac\x01\n\x07SetPair\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\x12\x1e\n\x05\x44type\x18\x03 \x01(\x0e\x32\n.bos.DtypeH\x00\x88\x01\x01\x12\n\n\x02Ok\x18\x04 \x01(\x08\x12!\n\x05\x45rror\x18\x05 \x01(\x0e\x32\r.bos.SetErrorH\x01\x88\x01\x01\x12\x15\n\x08\x45rrorMsg\x18\x06 \x01(\tH\x02\x88\x01\x01\x42\x08\n\x06_DtypeB\x08\n\x06_ErrorB\x0b\n\t_ErrorMsg\"7\n\nGetRequest\x12\x1b\n\x06Header\x18\x01 \x01(\x0b\x32\x0b.bos.Header\x12\x0c\n\x04Keys\x18\x02 \x03(\t\"\xac\x01\n\x0bGetResponse\x12 \n\x06Header\x18\x01 \x01(\x0b\x32\x0b.bos.HeaderH\x00\x88\x01\x01\x12\x1b\n\x05Pairs\x18\x02 \x03(\x0b\x32\x0c.bos.GetPair\x12%\n\x05\x45rror\x18\x03 \x01(\x0e\x32\x11.bos.ServiceErrorH\x01\x88\x01\x01\x12\x15\n\x08\x45rrorMsg\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\t\n\x07_HeaderB\x08\n\x06_ErrorB\x0b\n\t_ErrorMsg\"V\n\nSetRequest\x12 \n\x06Header\x18\x01 \x01(\x0b\x32\x0b.bos.HeaderH\x00\x88\x01\x01\x12\x1b\n\x05Pairs\x18\x02 \x03(\x0b\x32\x0c.bos.SetPairB\t\n\x07_Header\"\xac\x01\n\x0bSetResponse\x12 \n\x06Header\x18\x01 \x01(\x0b\x32\x0b.bos.HeaderH\x00\x88\x01\x01\x12\x1b\n\x05Pairs\x18\x02 \x03(\x0b\x32\x0c.bos.SetPair\x12%\n\x05\x45rror\x18\x03 \x01(\x0e\x32\x11.bos.ServiceErrorH\x01\x88\x01\x01\x12\x15\n\x08\x45rrorMsg\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\t\n\x07_HeaderB\x08\n\x06_ErrorB\x0b\n\t_ErrorMsg\"\xe8\x02\n\x11PointQueryRequest\x12 \n\x06Header\x18\x01 \x01(\x0b\x32\x0b.bos.HeaderH\x00\x88\x01\x01\x12\x12\n\x05Query\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x44\x65vice\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\r\n\x05Names\x18\x04 \x03(\t\x12\r\n\x05Types\x18\x05 \x03(\t\x12\x11\n\tLocations\x18\x06 \x03(\t\x12\x1e\n\x11\x43onsiderDeviceLoc\x18\x07 \x01(\x08H\x03\x88\x01\x01\x12!\n\x08Resource\x18\x08 \x01(\x0e\x32\n.bos.DtypeH\x04\x88\x01\x01\x12#\n\x05\x45rror\x18\x0b \x01(\x0e\x32\x0f.bos.QueryErrorH\x05\x88\x01\x01\x12\x15\n\x08\x45rrorMsg\x18\x0c \x01(\tH\x06\x88\x01\x01\x42\t\n\x07_HeaderB\x08\n\x06_QueryB\t\n\x07_DeviceB\x14\n\x12_ConsiderDeviceLocB\x0b\n\t_ResourceB\x08\n\x06_ErrorB\x0b\n\t_ErrorMsg\"\xe7\x01\n\rQueryResponse\x12 \n\x06Header\x18\x01 \x01(\x0b\x32\x0b.bos.HeaderH\x00\x88\x01\x01\x12\x12\n\x05Query\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06Values\x18\x03 \x03(\t\x12\x1e\n\x05\x44type\x18\x04 \x01(\x0e\x32\n.bos.DtypeH\x02\x88\x01\x01\x12#\n\x05\x45rror\x18\x05 \x01(\x0e\x32\x0f.bos.QueryErrorH\x03\x88\x01\x01\x12\x15\n\x08\x45rrorMsg\x18\x06 \x01(\tH\x04\x88\x01\x01\x42\t\n\x07_HeaderB\x08\n\x06_QueryB\x08\n\x06_DtypeB\x08\n\x06_ErrorB\x0b\n\t_ErrorMsg*\xa0\x01\n\x0cServiceError\x12\x16\n\x12SERVICE_ERROR_NONE\x10\x00\x12\x1d\n\x19SERVICE_ERROR_UNSPECIFIED\x10\x01\x12\x1d\n\x19SERVICE_ERROR_NO_RESPONSE\x10\x02\x12\x19\n\x15SERVICE_ERROR_TIMEOUT\x10\x03\x12\x1f\n\x1bSERVICE_ERROR_ACCESS_DENIED\x10\x07*\x83\x02\n\x08GetError\x12\x12\n\x0eGET_ERROR_NONE\x10\x00\x12\x19\n\x15GET_ERROR_UNSPECIFIED\x10\x01\x12 \n\x1cGET_ERROR_KEY_DOES_NOT_EXIST\x10\x02\x12\x15\n\x11GET_ERROR_TIMEOUT\x10\x03\x12&\n\"GET_ERROR_COULD_NOT_RESOLVE_DRIVER\x10\x04\x12$\n GET_ERROR_COULD_NOT_RESOLVE_ADDR\x10\x05\x12$\n GET_ERROR_COULD_NOT_RESOLVE_XREF\x10\x06\x12\x1b\n\x17GET_ERROR_ACCESS_DENIED\x10\x07*\xbe\x02\n\x08SetError\x12\x12\n\x0eSET_ERROR_NONE\x10\x00\x12\x19\n\x15SET_ERROR_UNSPECIFIED\x10\x01\x12 \n\x1cSET_ERROR_KEY_DOES_NOT_EXIST\x10\x02\x12\x15\n\x11SET_ERROR_TIMEOUT\x10\x03\x12&\n\"SET_ERROR_COULD_NOT_RESOLVE_DRIVER\x10\x04\x12$\n SET_ERROR_COULD_NOT_RESOLVE_ADDR\x10\x05\x12$\n SET_ERROR_COULD_NOT_RESOLVE_XREF\x10\x06\x12\x1b\n\x17SET_ERROR_ACCESS_DENIED\x10\x07\x12\x17\n\x13SET_ERROR_READ_ONLY\x10\x08\x12 \n\x1cSET_ERROR_INVALID_VALUE_TYPE\x10\t*\x97\x01\n\nQueryError\x12\x14\n\x10QUERY_ERROR_NONE\x10\x00\x12\x1b\n\x17QUERY_ERROR_UNSPECIFIED\x10\x01\x12\x17\n\x13QUERY_ERROR_TIMEOUT\x10\x03\x12\x1e\n\x1aQUERY_ERROR_UNKNOWN_PREFIX\x10\x04\x12\x1d\n\x19QUERY_ERROR_ACCESS_DENIED\x10\x05*\xab\x02\n\x05\x44type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04NULL\x10\x01\x12\n\n\x06\x44OUBLE\x10\n\x12\t\n\x05\x46LOAT\x10\x0b\x12\t\n\x05INT32\x10\x0c\x12\t\n\x05INT64\x10\r\x12\n\n\x06UINT32\x10\x0e\x12\n\n\x06UINT64\x10\x0f\x12\n\n\x06SINT32\x10\x10\x12\n\n\x06SINT64\x10\x11\x12\x0b\n\x07\x46IXED32\x10\x12\x12\x0b\n\x07\x46IXED64\x10\x13\x12\x0c\n\x08SFIXED32\x10\x14\x12\x0c\n\x08SFIXED64\x10\x15\x12\x08\n\x04\x42OOL\x10\x16\x12\n\n\x06STRING\x10\x17\x12\t\n\x05\x42YTES\x10\x18\x12\t\n\x05POINT\x10\x1e\x12\x0e\n\nPOINT_LIST\x10\x1f\x12\n\n\x06\x44\x45VICE\x10(\x12\x0f\n\x0b\x44\x45VICE_LIST\x10)\x12\n\n\x06\x44RIVER\x10\x30\x12\x0f\n\x0b\x44RIVER_XREF\x10\x31\x32_\n\tGetSetRun\x12(\n\x03Get\x12\x0f.bos.GetRequest\x1a\x10.bos.GetResponse\x12(\n\x03Set\x12\x0f.bos.SetRequest\x1a\x10.bos.SetResponse2\xcd\x02\n\x06Sysmod\x12\x32\n\x0bNameToPoint\x12\x0f.bos.GetRequest\x1a\x12.bos.QueryResponse\x12\x32\n\x0bPointToName\x12\x0f.bos.GetRequest\x1a\x12.bos.QueryResponse\x12\x32\n\x0bTypeToPoint\x12\x0f.bos.GetRequest\x1a\x12.bos.QueryResponse\x12\x36\n\x0fLocationToPoint\x12\x0f.bos.GetRequest\x1a\x12.bos.QueryResponse\x12\x39\n\x0bQueryPoints\x12\x16.bos.PointQueryRequest\x1a\x12.bos.QueryResponse\x12\x34\n\rGetDriverXref\x12\x0f.bos.GetRequest\x1a\x12.bos.QueryResponse2-\n\x0bHealthCheck\x12\x1e\n\x04Ping\x12\n.bos.Empty\x1a\n.bos.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'comms_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SERVICEERROR']._serialized_start=1510
  _globals['_SERVICEERROR']._serialized_end=1670
  _globals['_GETERROR']._serialized_start=1673
  _globals['_GETERROR']._serialized_end=1932
  _globals['_SETERROR']._serialized_start=1935
  _globals['_SETERROR']._serialized_end=2253
  _globals['_QUERYERROR']._serialized_start=2256
  _globals['_QUERYERROR']._serialized_end=2407
  _globals['_DTYPE']._serialized_start=2410
  _globals['_DTYPE']._serialized_end=2709
  _globals['_EMPTY']._serialized_start=20
  _globals['_EMPTY']._serialized_end=27
  _globals['_HEADER']._serialized_start=29
  _globals['_HEADER']._serialized_end=77
  _globals['_GETPAIR']._serialized_start=80
  _globals['_GETPAIR']._serialized_end=240
  _globals['_SETPAIR']._serialized_start=243
  _globals['_SETPAIR']._serialized_end=415
  _globals['_GETREQUEST']._serialized_start=417
  _globals['_GETREQUEST']._serialized_end=472
  _globals['_GETRESPONSE']._serialized_start=475
  _globals['_GETRESPONSE']._serialized_end=647
  _globals['_SETREQUEST']._serialized_start=649
  _globals['_SETREQUEST']._serialized_end=735
  _globals['_SETRESPONSE']._serialized_start=738
  _globals['_SETRESPONSE']._serialized_end=910
  _globals['_POINTQUERYREQUEST']._serialized_start=913
  _globals['_POINTQUERYREQUEST']._serialized_end=1273
  _globals['_QUERYRESPONSE']._serialized_start=1276
  _globals['_QUERYRESPONSE']._serialized_end=1507
  _globals['_GETSETRUN']._serialized_start=2711
  _globals['_GETSETRUN']._serialized_end=2806
  _globals['_SYSMOD']._serialized_start=2809
  _globals['_SYSMOD']._serialized_end=3142
  _globals['_HEALTHCHECK']._serialized_start=3144
  _globals['_HEALTHCHECK']._serialized_end=3189
# @@protoc_insertion_point(module_scope)
